@@ -54,7 +54,7 @@ def unvisited_closure():
 def find_subdomain_list_file(filename):
     # First check the list directory relative to where we are. This
     # will typically happen if they simply cloned the Github repository
-    filename_path = os.path.join("/usr/local/lib/python3.9/site-packages/fierce/", "lists", filename)
+    filename_path = os.path.join("/usr/local/lib/python3.10/site-packages/fierce/", "lists", filename)
     if os.path.exists(filename_path):
         return os.path.abspath(filename_path)
 
@@ -127,7 +127,7 @@ def query(resolver, domain, record_type='A', tcp=False):
             return query(resolver, domain, record_type, tcp=tcp)
 
         return None
-    except (dns.resolver.NXDOMAIN, dns.resolver.NoNameservers, dns.exception.Timeout):
+    except (dns.resolver.NXDOMAIN, dns.resolver.NoNameservers, dns.exception.Timeout, ValueError):
         return None
 
 
@@ -331,7 +331,7 @@ def fierce(**kwargs):
         pprint.pprint({k: v.to_text(k) for k, v in zone.items()})
         return
 
-    random_subdomain = str(random.randint(1e10, 1e11))
+    random_subdomain = str(random.randint(1e10, 1e11))  # noqa DUO102, non-cryptographic random use
     random_domain = concatenate_subdomains(domain, [random_subdomain])
     wildcard = query(resolver, random_domain, record_type='A', tcp=kwargs["tcp"])
     wildcard_ips = set(rr.address for rr in wildcard.rrset) if wildcard else set()
@@ -355,7 +355,12 @@ def fierce(**kwargs):
     unvisited = unvisited_closure()
 
     for subdomain in subdomains:
-        url = concatenate_subdomains(domain, [subdomain])
+        try:
+            url = concatenate_subdomains(domain, [subdomain])
+        except dns.exception.DNSException:
+            print("Error occured for subdomain: " + str(subdomain) + ". Skipping.")
+            continue
+
         record = query(resolver, url, record_type='A', tcp=kwargs["tcp"])
 
         if record is None or record.rrset is None:
